# removio

#### Remove any app from your Android device without root access.



## ☁️ Installation

You can install it with pip:

```bash
pip3 install removio
```



## :clipboard: Usage

![](https://imgur.com/5x8Q5LY.png)



![](https://imgur.com/QQVb9V8.png)

> You can uninstall multiple packages at once by separating them with space.